@@ -3,7 +3,7 @@ package CPAN::Plugin::Sysdeps::Mapping;
 use strict;
 use warnings;
 
-our $VERSION = '0.20';
+our $VERSION = '0.21';
 
 # shortcuts
 #  os and distros
@@ -49,6 +49,8 @@ sub mapping {
        [package => 'yasm']],
       [like_fedora,
        [package => 'yasm']],
+      [os_darwin,
+       [package => 'yasm']],
      ],
 
      [cpanmod => 'Alien::FFTW3',
@@ -188,7 +190,12 @@ sub mapping {
       [os_freebsd,
        [package => 'cfitsio']],
       [like_debian,
-       [package => 'libcfitsio3-dev']]],
+       [linuxdistrocodename => [qw(squeeze wheezy jessie precise xenial)],
+	[package => 'libcfitsio3-dev']],
+       [package => 'libcfitsio-dev']],
+      [like_fedora,
+       [package => 'cfitsio-devel']], # but test fails on CentOS7 (undefined symbol: ffgsky)
+     ],
 
      [cpanmod => 'Astro::WCS::LibWCS',
       ## not checked:
@@ -201,7 +208,10 @@ sub mapping {
       [os_freebsd,
        [package => 'libao']],
       [like_debian,
-       [package => 'libao-dev']]],
+       [package => 'libao-dev']],
+      [like_fedora,
+       [package => 'libao-devel']],
+     ],
 
      [cpanmod => 'Audio::Audiere',
       [os_freebsd,
@@ -398,13 +408,17 @@ sub mapping {
        [package => 'libcomedi-dev']],
      ],
 
-     [cpanmod => ['Compress::LZMA::Simple', 'Compress::Raw::Lzma'],
+     [cpanmod => 'Compress::LZMA::Simple',
       [os_freebsd,
-       # this one does not work with Compress::Raw::Lzma under freebsd
        [package => 'lzmalib']],
+     ],
+      
+     [cpanmod => 'Compress::Raw::Lzma',
       [like_debian,
-       # this one does not work with Compress::LZMA::Simple under debian
-       [package => 'liblzma-dev']]],
+       [package => 'liblzma-dev']],
+      [os_darwin,
+       [package => 'xz']],
+     ],
 
      # Try also the patches listed in
      # https://rt.cpan.org/Ticket/Display.html?id=86115
@@ -413,14 +427,22 @@ sub mapping {
       [os_freebsd,
        [package => 'lzo2']],
       [like_debian,
-       [package => 'liblzo2-dev']]],
+       [package => 'liblzo2-dev']],
+      [like_fedora,
+       [package => 'lzo-devel']],
+     ],
 
      [cpanmod => 'Config::Augeas',
       [os_freebsd,
        [package => ['augeas', 'pkgconf']]],
       [like_debian,
        # but the wheezy version is too old, module wants 1.0.0, wheezy has 0.10.0
-       [package => ['libaugeas-dev', 'pkg-config | pkgconf']]]],
+       [package => ['libaugeas-dev', 'pkg-config | pkgconf']]],
+      [like_fedora,
+       [package => 'augeas-devel']],
+      [os_darwin,
+       [package => 'augeas']],
+     ],
 
      [cpanmod => 'Crypt::Cracklib',
       [os_freebsd,
@@ -454,7 +476,7 @@ sub mapping {
        # Neither libgcrypt11 nor libgcrypt20 seem to work.
        [package => 'libgcrypt11-dev']]],
 
-     [cpanmod => 'Crypt::MCrypt',
+     [cpanmod => ['Crypt::MCrypt', 'Mcrypt'],
       [os_freebsd,
        [package => 'libmcrypt']],
       [like_debian,
@@ -560,9 +582,8 @@ sub mapping {
        [package => 'libmpfr-dev']],
       [like_fedora,
        [package => 'mpfr-devel']],
-      ## Does not work:
-      #[os_darwin,
-      # [package => 'mpfr']],
+      [os_darwin,
+       [package => 'mpfr']],
      ],
 
      [cpanmod => 'DB_File',
@@ -599,7 +620,10 @@ sub mapping {
       [os_freebsd,
        [package => 'unixODBC']],
       [like_debian,
-       [package => 'unixodbc-dev']]],
+       [package => 'unixodbc-dev']],
+      [like_fedora,
+       [package => 'libiodbc-devel']], # but building does not work out of the box, Makefile.PL needs patching
+     ],
 
      [cpanmod => 'DBD::Pg',
       [os_freebsd,
@@ -608,6 +632,8 @@ sub mapping {
        [package => 'libpq-dev']],
       [like_fedora,
        [package => [qw(postgresql postgresql-devel)]]],
+      [os_darwin,
+       [package => 'postgresql']],
      ],
 
      [cpanmod => 'Deliantra::Client',
@@ -692,6 +718,8 @@ sub mapping {
        [package => 'adns']],
       [like_debian,
        [package => 'libadns1-dev']],
+      [os_darwin,
+       [package => 'adns']],
       # no package available for CentOS7
      ],
 
@@ -894,6 +922,8 @@ sub mapping {
      [cpanmod => 'Glib',
       [like_fedora,
        [package => 'gobject-introspection-devel']],
+      [os_darwin,
+       [package => 'glib']],
      ],
 
      [cpanmod => 'Glib::Object::Introspection',
@@ -1061,13 +1091,18 @@ sub mapping {
       [os_freebsd,
        [package => 'gtksourceview3']],
       [like_debian,
-       [package => 'libgtksourceview-3.0-dev']]],
+       [package => 'libgtksourceview-3.0-dev']],
+      [like_fedora,
+       [package => 'gtksourceview3-devel']],
+     ],
 
      [cpanmod => 'Gtk3::WebKit',
       [os_freebsd,
        [package => 'webkit-gtk3']],
       [like_debian,
        [package => 'libwebkitgtk-3.0-dev']],
+      [like_fedora,
+       [package => 'webkitgtk3-devel']],
      ],
 
      [cpanmod => 'GTop',
@@ -1110,6 +1145,8 @@ sub mapping {
      [cpanmod => 'HTML::Tidy',
       [os_freebsd,
        [package => 'tidyp']],
+      [os_darwin,
+       [package => 'tidyp']],
       # linux: Alien::Tidyp works fine, no external dependency required
      ],
 
@@ -1145,6 +1182,8 @@ sub mapping {
        [package => 'libimlib2-dev']],
       [like_fedora,
        [package => 'imlib2-devel']],
+      [os_darwin,
+       [package => 'imlib2']],
      ],
 
      [cpanmod => 'Image::LibExif',
@@ -1569,7 +1608,10 @@ sub mapping {
       [os_freebsd,
        [package => ['dbus', 'pkgconf']]],
       [like_debian,
-       [package => ['libdbus-1-dev', 'pkg-config | pkgconf']]]],
+       [package => ['libdbus-1-dev', 'pkg-config | pkgconf']]],
+      [os_darwin,
+       [package => 'dbus']],
+     ],
 
      [cpanmod => 'Net::DBus::GLib',
       [os_freebsd,
@@ -1600,6 +1642,8 @@ sub mapping {
        [package => 'libdumbnet-dev']],
       [like_fedora,
        [package => 'libdnet-devel']],
+      [os_darwin,
+       [package => 'libdnet']],
      ],
 
      [cpanmod => 'Net::LibIDN',
@@ -1609,6 +1653,8 @@ sub mapping {
        [package => 'libidn11-dev']],
       [like_fedora,
        [package => 'libidn-devel']],
+      [os_darwin,
+       [package => 'libidn']],
      ],
 
      [cpanmod => 'Net::NfDump',
@@ -1685,7 +1731,10 @@ sub mapping {
       [os_freebsd,
        [package => 'yaz']],
       [like_debian,
-       [package => 'libyaz-dev']]],
+       [package => 'libyaz-dev']],
+      [os_darwin,
+       [package => 'yaz']],
+     ],
 
      [cpanmod => ['Net::ZooKeeper', 'ZooKeeper'],
       [os_freebsd,
@@ -1999,6 +2048,8 @@ sub mapping {
       [like_fedora,
        [# test needs also English dictionary
 	package => ['aspell-devel', 'aspell-en']]],
+      [os_darwin,
+       [package => 'aspell']],
      ],
 
      [cpanmod => 'Text::Bidi',
@@ -2224,12 +2275,14 @@ sub mapping {
       [os_freebsd,
        [package => 'imlib2']],
       [like_debian,
-       [package => 'imlib2-dev']]],
+       [package => 'libimlib2-dev']]],
 
      [cpanmod => 'X11::GUITest',
+      # XXX what about freebsd?
       [like_debian,
        [package => ['libxt-dev', 'libxtst-dev']]],
-      # XXX what about freebsd
+      [like_fedora,
+       [package => 'libXtst-devel']],
      ],
 
      [cpanmod => 'X11::XCB',
@@ -2242,7 +2295,10 @@ sub mapping {
       [os_freebsd,
        [package => 'libzmq4']], # seems to hang with nonthreaded perls on freebsd, wait-and-kill rule exists
       [like_debian,
-       [package => 'libzmq-dev']]],
+       [package => 'libzmq-dev']],
+      [os_darwin,
+       [package => 'zmq']],
+     ],
 
      [cpanmod => 'ZMQ::LibZMQ4',
       [os_freebsd,
